<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"] ?: array()) + array("_9b16fa2683095e67d7" . "c8b265a8081d0b" => base64_decode("TWFpbFJlY2VpdmVkRXZ" . "lbnRSZWNlaXZlcg=="), "_376d30c4085" . "7357a4d4cbb1" . "ffaa25817" => base64_decode("d" . "G" . "8" . "="), "_ced92d7b391285c8a26846f1f4bd312" . "8" => base64_decode("Ym9keV90ZXh" . "0"), "_c35473364fa" . "7a050299058f" . "332ec29c1" => base64_decode("ZXhjZXB" . "0aW9u"), "_f656816961e8573806141c" . "558b184fe2" => base64_decode("c3ViamVjdA" . "=="), "_03b1f0cee835582d1158dc" . "e2678b505c" => base64_decode("U3RhcnRpbmcgaW5mb2NhcHR1cmU" . "gbWFpbCByZWNlaXZlZCBzdWJzY3" . "JpYmVy"), "_5d40a2cf1c525fb252bf5599e339" . "fdd0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvamVjdCB3YXMgaWRlbnRpZmllZCBmb3IgbWF" . "pbDsgc3ViamVjdCAn"), "projec" . "t_id" => base64_decode("cHJvamV" . "jdF9pZA" . "=="), "_67a0d624aebcceb0ab" . "d5ce56a53ff06f" => base64_decode("ZGF0" . "ZQ=="), "_460e1aeb3113a1" . "676ce59a8f40431" . "d5c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3MgZW" . "1haWwgZm9yIGluZm9jYXB0dXJl" . "IHByb2plY3Q="), "_a3d82c5df38e194c9c73e3cc" . "b4223bbc" => base64_decode("ZW1haWxfZGF0YQ=" . "="), "_618a4aeb9fecc4592a4521f34876f" . "a29" => base64_decode("ZnJ" . "vbQ" . "=="), "_e608e5b" . "5c4c34a6" . "7ba97ef8" . "4c1e1619" . "9" => base64_decode("Jw" . "=="), "_bfda889b74ea561b1432" . "5e30e7d75426" => base64_decode("Ym9keV9od" . "G1s"));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_9b16fa2683095e67" . "d7c8b265a8081d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_03b1f0cee835582d1158dce2678b5" . "05c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_5d40a2cf1c525f" . "b252bf5599e339f" . "dd0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_e608e5b5c4" . "c34a67ba97e" . "f84c1e16199"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_618a4aeb9fecc4592a4" . "521f34876fa29"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_376d30c40857357a4d4cbb1ffaa" . "25817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_f65681696" . "1e85738061" . "41c558b184" . "fe2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_ced92d7b" . "391285c8a" . "26846f1f4" . "bd3128"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_bfda889b74ea" . "561b14325e30e" . "7d75426"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_67a0d624aebcceb0ab" . "d5ce56a53ff06f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_460e1aeb3113a1676ce59a8f4043" . "1d5c"], [$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["proje" . "ct_id"] => $project->GetId(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_a3d82c5df38e194c9c73e" . "3ccb4223bbc"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_c35473364fa7a050299058f332ec29" . "c1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}